@@ -1,4 +1,4 @@
 from .plot_colors import plot_colors
-from .plot_intensity import plot_intensity
+from .plot_intensity import plot_intensity, plot_farfield, plot_farfield_spherical_coordinates
 from .plot_phase import plot_phase
 from .plot_longitudinal_profile import plot_longitudinal_profile_colors, plot_longitudinal_profile_intensity
\ No newline at end of file
